==> brasil.gov.portal-1.1.3-py2-none-any.whl: brasil/gov/portal/content/audio.py <==
# -*- coding: utf-8 -*-
from brasil.gov.portal.content.audio_file import IMPEGAudioFile
from brasil.gov.portal.content.audio_file import IOGGAudioFile
from five import grok
from plone.dexterity.content import Container
from zope.interface import Interface
from zope.interface import implements
from zope.lifecycleevent.interfaces import IObjectAddedEvent
from zope.lifecycleevent.interfaces import IObjectRemovedEvent


class IAudio(Interface):
    ''' Representa um Audio '''


class Audio(Container):
    implements(IAudio)

    def return_ogg(self):
        sources = self.objectValues()
        for source in sources:
            if IOGGAudioFile.providedBy(source):
                return source

    def return_mp3(self):
        sources = self.objectValues()
        for source in sources:
            if IMPEGAudioFile.providedBy(source):
                return source


@grok.subscribe(IObjectAddedEvent)
def object_added(event, obj=None):
    if not obj:
        obj = event.object
    parent = event.newParent
    if IAudio.providedBy(parent):
        if IMPEGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add MPEG File'
        elif IOGGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add OGG File'
        if permission:
            parent.manage_permission(permission, roles=[], acquire=0)


@grok.subscribe(IObjectRemovedEvent)
def object_removed(event, obj=None):
    if not obj:
        obj = event.object
    parent = event.oldParent
    if IAudio.providedBy(parent):
        if IMPEGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add MPEG File'
        elif IOGGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add OGG File'
        if permission:
            parent.manage_permission(permission, roles=[], acquire=1)

==> brasil.gov.portal-1.5.5-py2-none-any.whl: brasil/gov/portal/content/audio.py <==
# -*- coding: utf-8 -*-
"""Audio content type and subscribers associated with it.

An Audio is a container of audio formats: MP3 (MPEGAudioFile) and
Vorbis (OGGAudioFile) and can only hold one file of each format,
that's is handled by a couple of subscribers.
"""
from brasil.gov.portal.content.audio_file import IMPEGAudioFile
from brasil.gov.portal.content.audio_file import IOGGAudioFile
from plone.dexterity.content import Container
from zope.interface import implements
from zope.interface import Interface


class IAudio(Interface):
    """An Audio (in fact a container of audio formats)."""


class Audio(Container):
    implements(IAudio)

    def return_ogg(self):
        """Return the Vorbis version of the audio."""
        sources = self.objectValues()
        for source in sources:
            if IOGGAudioFile.providedBy(source):
                return source

    def return_mp3(self):
        """Return the MP3 version of the audio."""
        sources = self.objectValues()
        for source in sources:
            if IMPEGAudioFile.providedBy(source):
                return source


def object_added(obj, event):
    """Remove further permission to add a file type after adding it."""
    parent = event.newParent
    if IAudio.providedBy(parent):
        if IMPEGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add MPEG File'
        elif IOGGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add OGG File'
        if permission:
            parent.manage_permission(permission, roles=[], acquire=0)


def object_removed(obj, event):
    """Grant permission to add a file type after removing it."""
    parent = event.oldParent
    if IAudio.providedBy(parent):
        if IMPEGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add MPEG File'
        elif IOGGAudioFile.providedBy(obj):
            permission = 'brasil.gov.portal: Add OGG File'
        if permission:
            parent.manage_permission(permission, roles=[], acquire=1)
